# metric-config-parser

This package parses configuration files that are compatible with [jetstream](https://github.com/mozilla/jetstream) and [opmon](https://github.com/mozilla/opmon) compatible configuration files.

## Installation

`pip install mozilla-metric-config-parser`

